==> DeepCell-CPU-0.10.2.tar.gz: DeepCell-CPU-0.10.2/deepcell/_version.py <==
# Copyright 2016-2021 The Van Valen Lab at the California Institute of
# Technology (Caltech), with support from the Paul Allen Family Foundation,
# Google, & National Institutes of Health (NIH) under Grant U24CA224309-01.
# All rights reserved.
#
# Licensed under a modified Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.github.com/vanvalenlab/deepcell-tf/LICENSE
#
# The Work provided may be used for non-commercial academic purposes only.
# For any other use of the Work, including commercial use, please contact:
# vanvalenlab@gmail.com
#
# Neither the name of Caltech nor the names of its contributors may be used
# to endorse or promote products derived from this software without specific
# prior written permission.
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ==============================================================================

__title__ = 'DeepCell-CPU'
__description__ = 'Deep learning for single cell image segmentation'
__url__ = 'https://github.com/vanvalenlab/deepcell-tf'
__version__ = '0.10.2'
__download_url__ = '{}/tarball/{}'.format(__url__, __version__)
__author__ = 'The Van Valen Lab'
__author_email__ = 'vanvalen@caltech.edu'
__license__ = 'LICENSE'
__copyright__ = 'Copyright 2016-2021 The Van Valen Lab at the ' \
    'California Institute of Technology (Caltech)'

==> DeepCell-CPU-0.11.0rc1.tar.gz: DeepCell-CPU-0.11.0rc1/deepcell/_version.py <==
# Copyright 2016-2021 The Van Valen Lab at the California Institute of
# Technology (Caltech), with support from the Paul Allen Family Foundation,
# Google, & National Institutes of Health (NIH) under Grant U24CA224309-01.
# All rights reserved.
#
# Licensed under a modified Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.github.com/vanvalenlab/deepcell-tf/LICENSE
#
# The Work provided may be used for non-commercial academic purposes only.
# For any other use of the Work, including commercial use, please contact:
# vanvalenlab@gmail.com
#
# Neither the name of Caltech nor the names of its contributors may be used
# to endorse or promote products derived from this software without specific
# prior written permission.
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ==============================================================================

__title__ = 'DeepCell-CPU'
__description__ = 'Deep learning for single cell image segmentation'
__url__ = 'https://github.com/vanvalenlab/deepcell-tf'
__version__ = '0.11.0-rc1'
__download_url__ = '{}/tarball/{}'.format(__url__, __version__)
__author__ = 'The Van Valen Lab'
__author_email__ = 'vanvalen@caltech.edu'
__license__ = 'LICENSE'
__copyright__ = 'Copyright 2016-2021 The Van Valen Lab at the ' \
    'California Institute of Technology (Caltech)'
